![Super Kafka Client JS](Kafkas://i.imgur.com/6H0paOE.jpg)

<div align="center">
  <h1>Super Kafka Client JS</h1>
</div>

## What is Super Kafka Client?

Kafka Client lib for Node.js & TypeScript developed by Superlógica Tecnologias S.A

## Getting started

To install the lib just run the command:

```bash
npm install @superlogica/super-kafka-client-js
```

Ready!

Now you can use the available interfaces, adapters and factories.

## How Works?

### Create Kafka Consumer

Start by creating a consumer:

```ts
import { makeConsumerMessageBroker, ConsumerType } from '@superlogica/super-kafka-client-js'

import { ExampleError } from './example-error'
import { ExampleMessageHandler } from './example-message-handler'
import { makeExampleService } from './example-service-factory'

const TOPIC = 'topic.name'
const GROUP_ID = `${process.env.APP_NAME}-consumer-group`

export class ConsumeExample {
  static make(): ConsumerType {
    const processMessage = new ExampleMessageHandler(
      makeExampleService(),
    )
    return makeConsumerMessageBroker<ExampleMessageHandler.Message>(
      {
        topics: [TOPIC],
        groupId: GROUP_ID,
        directDqlErrors: [ExampleError]
      },
      processMessage
    )
  }
}
```

Or start by creating a producer:

```ts
import { makeProducerMessageBroker, ProducerType } from '@superlogica/super-kafka-client-js'

import { ExampleError } from './example-error'
import { ExampleMessageHandler } from './example-message-handler'
import { makeExampleService } from './example-service-factory'

const TOPIC = 'topic.name'

export class ProduceExample {
  private static instance: ProducerType

  static make(): ProducerType {
    if (!this.instance) {
      const processMessage = new ExampleMessageHandler()
      this.instance = makeProducerMessageBroker(
        {
          topic: TOPIC
        },
        processMessage
      )
    }
    return this.instance
  }
}
```

# ENV Vars

Add vars:

process.env.APP_NAME                          // 'broker:29092'
process.env.KAFKA_SECURITY_PROTOCOL           // 'PLAINTEXT'
process.env.KAFKA_SASL_MECHANISM              // 'PLAIN'
process.env.KAFKA_SASL_USERNAME               // 'user'
process.env.KAFKA_SASL_PASSWORD               // '123'
process.env.KAFKA_GROUP_ID                    // `${appConfig.name}-default-consumer-group`
process.env.KAFKA_AUTO_OFFSET_RESET           // 'earliest'
process.env.KAFKA_ENABLE_AUTO_COMMIT          // false
process.env.KAFKA_ENABLE_PARTITION_EOF        // true
process.env.APP_CONSUMERS                     // 'NULL' 
process.env.KAFKA_LOG_MESSAGE_PAYLOAD         // false
